[Scummvm-git-logs] scummvm master -> 4f761d60028a3bc5263e199993cacf3605921ced

bluegr bluegr at gmail.com
Sun Dec 23 17:39:17 CET 2018


This automated email contains information about 14 new commits which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
0a474f2a1a CREATE_PROJECT: Fix MSVC warnings
f08e7a3012 MSVC: Replace MinimalRebuild with MultiProcessor flag
88b6959cb4 MSVC: Fix HashMap visualisation showing dummy nodes
3482d9bacf MSVC: Fix List visualisation showing infinite nodes
8352986b88 MSVC: Cleanup natvis properties
f6c37b09ea MSVC: Add visualisations for iterators and pointers
5004c331c9 MSVC: Fix natvis not being added to project in VS2017
35ea621a4e MSVC: Add visualiser for unicode strings
ddb3b6fba7 MSVC: Fix resource file not including translations.dat
47b55f29c5 MSVC: Fix resource file revision include error
b66711da04 MSVC: Fix unquoted paths in build events
3091345af3 MSVC: Update post-build installer for Inno Setup
e6a80868c6 MSVC: Update DLL paths in post-build script
4f761d6002 BUILD: Update MSVC versions in ideprojects target


Commit: 0a474f2a1a2aa1d4254f08c66070d1dfcdfb48cc
    https://github.com/scummvm/scummvm/commit/0a474f2a1a2aa1d4254f08c66070d1dfcdfb48cc
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
CREATE_PROJECT: Fix MSVC warnings

Changed paths:
    devtools/create_project/msvc10/create_project.vcxproj
    devtools/create_project/msvc11/create_project.vcxproj
    devtools/create_project/msvc12/create_project.vcxproj
    devtools/create_project/msvc14/create_project.vcxproj
    devtools/create_project/msvc15/create_project.vcxproj
    devtools/create_project/msvc9/create_project.vcproj


diff --git a/devtools/create_project/msvc10/create_project.vcxproj b/devtools/create_project/msvc10/create_project.vcxproj
index 0386c3e..bc6f634 100644
--- a/devtools/create_project/msvc10/create_project.vcxproj
+++ b/devtools/create_project/msvc10/create_project.vcxproj
@@ -50,7 +50,7 @@
       <WarningLevel>Level4</WarningLevel>
       <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
       <DisableLanguageExtensions>false</DisableLanguageExtensions>
-      <DisableSpecificWarnings>4003;4512;4127;4100</DisableSpecificWarnings>
+      <DisableSpecificWarnings>4003;4512;4127;4100;4244</DisableSpecificWarnings>
     </ClCompile>
     <Link>
       <AdditionalDependencies>Rpcrt4.lib;%(AdditionalDependencies)</AdditionalDependencies>
diff --git a/devtools/create_project/msvc11/create_project.vcxproj b/devtools/create_project/msvc11/create_project.vcxproj
index 9168163..74fa937 100644
--- a/devtools/create_project/msvc11/create_project.vcxproj
+++ b/devtools/create_project/msvc11/create_project.vcxproj
@@ -53,7 +53,7 @@
       <WarningLevel>Level4</WarningLevel>
       <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
       <DisableLanguageExtensions>false</DisableLanguageExtensions>
-      <DisableSpecificWarnings>4003;4512;4127;4100</DisableSpecificWarnings>
+      <DisableSpecificWarnings>4003;4512;4127;4100;4244</DisableSpecificWarnings>
     </ClCompile>
     <Link>
       <AdditionalDependencies>Rpcrt4.lib;%(AdditionalDependencies)</AdditionalDependencies>
diff --git a/devtools/create_project/msvc12/create_project.vcxproj b/devtools/create_project/msvc12/create_project.vcxproj
index 0623b24..f8afe4c 100644
--- a/devtools/create_project/msvc12/create_project.vcxproj
+++ b/devtools/create_project/msvc12/create_project.vcxproj
@@ -52,7 +52,7 @@
       <WarningLevel>Level4</WarningLevel>
       <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
       <DisableLanguageExtensions>false</DisableLanguageExtensions>
-      <DisableSpecificWarnings>4003;4512;4127;4100</DisableSpecificWarnings>
+      <DisableSpecificWarnings>4003;4512;4127;4100;4244</DisableSpecificWarnings>
     </ClCompile>
     <Link>
       <AdditionalDependencies>Rpcrt4.lib;%(AdditionalDependencies)</AdditionalDependencies>
diff --git a/devtools/create_project/msvc14/create_project.vcxproj b/devtools/create_project/msvc14/create_project.vcxproj
index aec8c94..1ac132d 100644
--- a/devtools/create_project/msvc14/create_project.vcxproj
+++ b/devtools/create_project/msvc14/create_project.vcxproj
@@ -76,7 +76,7 @@
       <WarningLevel>Level4</WarningLevel>
       <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
       <DisableLanguageExtensions>false</DisableLanguageExtensions>
-      <DisableSpecificWarnings>4003;4512;4127;4100</DisableSpecificWarnings>
+      <DisableSpecificWarnings>4003;4512;4127;4100;4244</DisableSpecificWarnings>
       <ExceptionHandling>Sync</ExceptionHandling>
     </ClCompile>
     <Link>
diff --git a/devtools/create_project/msvc15/create_project.vcxproj b/devtools/create_project/msvc15/create_project.vcxproj
index 24e579f..1ead51c 100644
--- a/devtools/create_project/msvc15/create_project.vcxproj
+++ b/devtools/create_project/msvc15/create_project.vcxproj
@@ -70,13 +70,12 @@
   <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
     <ClCompile>
       <Optimization>Disabled</Optimization>
-      <MinimalRebuild>true</MinimalRebuild>
       <BasicRuntimeChecks>EnableFastChecks</BasicRuntimeChecks>
       <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
       <WarningLevel>Level4</WarningLevel>
       <DebugInformationFormat>EditAndContinue</DebugInformationFormat>
       <DisableLanguageExtensions>false</DisableLanguageExtensions>
-      <DisableSpecificWarnings>4003;4512;4127;4100</DisableSpecificWarnings>
+      <DisableSpecificWarnings>4003;4512;4127;4100;4244</DisableSpecificWarnings>
       <ExceptionHandling>Sync</ExceptionHandling>
     </ClCompile>
     <Link>
diff --git a/devtools/create_project/msvc9/create_project.vcproj b/devtools/create_project/msvc9/create_project.vcproj
index f348226..0069f2a 100644
--- a/devtools/create_project/msvc9/create_project.vcproj
+++ b/devtools/create_project/msvc9/create_project.vcproj
@@ -45,7 +45,7 @@
 				RuntimeLibrary="3"
 				WarningLevel="4"
 				DebugInformationFormat="4"
-				DisableSpecificWarnings="4003;4512;4127;4100"
+				DisableSpecificWarnings="4003;4512;4127;4100;4244"
 			/>
 			<Tool
 				Name="VCManagedResourceCompilerTool"


Commit: f08e7a301241f0b17ad4362063abacdc1fd8a90b
    https://github.com/scummvm/scummvm/commit/f08e7a301241f0b17ad4362063abacdc1fd8a90b
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
MSVC: Replace MinimalRebuild with MultiProcessor flag

MinimalRebuild is obsolete and MultiProcessorCompilation yields better performance.

Changed paths:
    devtools/create_project/msbuild.cpp


diff --git a/devtools/create_project/msbuild.cpp b/devtools/create_project/msbuild.cpp
index 762b3e4..485e8b4 100644
--- a/devtools/create_project/msbuild.cpp
+++ b/devtools/create_project/msbuild.cpp
@@ -393,6 +393,7 @@ void MSBuildProvider::outputGlobalPropFile(const BuildSetup &setup, std::ofstrea
 	properties << "\t\t\t<WarningLevel>Level4</WarningLevel>\n"
 	              "\t\t\t<TreatWarningAsError>false</TreatWarningAsError>\n"
 	              "\t\t\t<CompileAs>Default</CompileAs>\n"
+	              "\t\t\t<MultiProcessorCompilation>true</MultiProcessorCompilation>\n"
 	              "\t\t</ClCompile>\n"
 	              "\t\t<Link>\n"
 	              "\t\t\t<IgnoreSpecificDefaultLibraries>%(IgnoreSpecificDefaultLibraries)</IgnoreSpecificDefaultLibraries>\n"
@@ -450,7 +451,6 @@ void MSBuildProvider::createBuildProp(const BuildSetup &setup, bool isRelease, b
 	} else {
 		properties << "\t\t\t<Optimization>Disabled</Optimization>\n"
 		              "\t\t\t<PreprocessorDefinitions>WIN32;" << (configuration == "LLVM" ? "_CRT_SECURE_NO_WARNINGS;" : "") << "%(PreprocessorDefinitions)</PreprocessorDefinitions>\n"
-		              "\t\t\t<MinimalRebuild>true</MinimalRebuild>\n"
 		              "\t\t\t<BasicRuntimeChecks>EnableFastChecks</BasicRuntimeChecks>\n"
 		              "\t\t\t<RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>\n"
 		              "\t\t\t<FunctionLevelLinking>true</FunctionLevelLinking>\n"


Commit: 88b6959cb4a2114771d22b546f43cbdbae8f2419
    https://github.com/scummvm/scummvm/commit/88b6959cb4a2114771d22b546f43cbdbae8f2419
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
MSVC: Fix HashMap visualisation showing dummy nodes

Changed paths:
    devtools/create_project/scripts/scummvm.natvis


diff --git a/devtools/create_project/scripts/scummvm.natvis b/devtools/create_project/scripts/scummvm.natvis
index 9956686..e305bea 100644
--- a/devtools/create_project/scripts/scummvm.natvis
+++ b/devtools/create_project/scripts/scummvm.natvis
@@ -10,8 +10,6 @@
     * Lists appear to be infinite (the same elements repeat over and over again).
       Unfortunately, Lists don't store length information, and it's not possible to
       detect whether a Node is the last one by the Node itself.
-
-    * In HashMaps, missing and dummy nodes are shown along with the useful ones.
 -->
 
 <AutoVisualizer xmlns="http://schemas.microsoft.com/vstudio/debugger/natvis/2010">
@@ -56,13 +54,22 @@
       <Item Name="[size]">_size</Item>
       <Item Name="[capacity]">_mask + 1</Item>
       <Item Name="[deleted]">_deleted</Item>
-      <IndexListItems>
-        <Size>_mask + 1</Size>
-        <ValueNode Condition="_storage[$i] && _storage[$i] != (Common::HashMap<$T1,$T2,$T3,$T4>::Node *)1">*_storage[$i]</ValueNode>
-      </IndexListItems>
+      <CustomListItems MaxItemsPerView="5000" ExcludeView="Test">
+        <Variable Name="ctr" InitialValue="0" />
+        <Size>_size</Size>
+        <Loop>
+          <Break Condition="ctr > _mask" />
+          <Item Condition="_storage[ctr] > 1" Name="[{_storage[ctr]->_key}]">*_storage[ctr],view(MapHelper)</Item>
+          <Exec>ctr++</Exec>
+        </Loop>
+      </CustomListItems>
     </Expand>
   </Type>
 
+  <Type Name="Common::HashMap<*,*,*,*>::Node" IncludeView="MapHelper">
+    <DisplayString>{_value}</DisplayString>
+  </Type>
+
   <Type Name="Common::List<*>">
     <DisplayString Condition="&_anchor == _anchor._next">{{ empty }}</DisplayString>
     <DisplayString Condition="&_anchor != _anchor._next">{{ non-empty }}</DisplayString>


Commit: 3482d9bacfea8242868c4486caad3d080af6cb1e
    https://github.com/scummvm/scummvm/commit/3482d9bacfea8242868c4486caad3d080af6cb1e
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
MSVC: Fix List visualisation showing infinite nodes

Changed paths:
    devtools/create_project/scripts/scummvm.natvis


diff --git a/devtools/create_project/scripts/scummvm.natvis b/devtools/create_project/scripts/scummvm.natvis
index e305bea..855ab28 100644
--- a/devtools/create_project/scripts/scummvm.natvis
+++ b/devtools/create_project/scripts/scummvm.natvis
@@ -4,12 +4,6 @@
     Debug visualizers for a few common ScummVM types for Visual Studio 2012 and up.
 
     To use, copy this file into Documents\Visual Studio 20xx\Visualizers.
-
-    Known issues:
-
-    * Lists appear to be infinite (the same elements repeat over and over again).
-      Unfortunately, Lists don't store length information, and it's not possible to
-      detect whether a Node is the last one by the Node itself.
 -->
 
 <AutoVisualizer xmlns="http://schemas.microsoft.com/vstudio/debugger/natvis/2010">
@@ -74,11 +68,15 @@
     <DisplayString Condition="&_anchor == _anchor._next">{{ empty }}</DisplayString>
     <DisplayString Condition="&_anchor != _anchor._next">{{ non-empty }}</DisplayString>
     <Expand>
-      <LinkedListItems Condition="&_anchor != _anchor._next">
-        <HeadPointer>_anchor._next</HeadPointer>
-        <NextPointer>_next</NextPointer>
-        <ValueNode>((Common::ListInternal::Node<$T1>*)this)->_data</ValueNode>
-      </LinkedListItems>
+      <CustomListItems Condition="&_anchor != _anchor._next">
+        <Variable Name="head" InitialValue="&_anchor"/>
+        <Variable Name="iter" InitialValue="_anchor._next"/>
+        <Loop>
+          <Break Condition="iter == head"/>
+          <Item>((Common::ListInternal::Node<$T1>*)iter)->_data</Item>
+          <Exec>iter = iter->_next</Exec>
+        </Loop>
+      </CustomListItems>
     </Expand>
   </Type>
 


Commit: 8352986b8891beb923abd7fc12880386384da0bb
    https://github.com/scummvm/scummvm/commit/8352986b8891beb923abd7fc12880386384da0bb
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
MSVC: Cleanup natvis properties

Changed paths:
    devtools/create_project/scripts/scummvm.natvis


diff --git a/devtools/create_project/scripts/scummvm.natvis b/devtools/create_project/scripts/scummvm.natvis
index 855ab28..74003dd 100644
--- a/devtools/create_project/scripts/scummvm.natvis
+++ b/devtools/create_project/scripts/scummvm.natvis
@@ -20,6 +20,9 @@
       </Synthetic>
       <Item Name="[channels]" Condition="format.bytesPerPixel==1">1</Item>
       <Item Name="[channels]" Condition="format.bytesPerPixel==2">2</Item>
+      <Synthetic Name="[channels]" Condition="format.bytesPerPixel==3">
+        <DisplayString>RGB</DisplayString>
+      </Synthetic>
       <Synthetic Name="[channels]" Condition="format.bytesPerPixel==4">
         <DisplayString>RGBA</DisplayString>
       </Synthetic>
@@ -31,7 +34,7 @@
   </Type>
 
   <Type Name="Common::Array<*>">
-    <DisplayString>{{size = {_size}}}</DisplayString>
+    <DisplayString>{{ size={_size} }}</DisplayString>
     <Expand>
       <Item Name="[size]">_size</Item>
       <Item Name="[capacity]">_capacity</Item>
@@ -43,7 +46,7 @@
   </Type>
 
   <Type Name="Common::HashMap<*,*,*,*>">
-    <DisplayString>{{ size = {_size} }}</DisplayString>
+    <DisplayString>{{ size={_size} }}</DisplayString>
     <Expand>
       <Item Name="[size]">_size</Item>
       <Item Name="[capacity]">_mask + 1</Item>
@@ -81,8 +84,8 @@
   </Type>
 
   <Type Name="Common::String">
-    <DisplayString>{_str,[_size]}</DisplayString>
-    <StringView>_str,[_size]</StringView>
+    <DisplayString>{_str,na}</DisplayString>
+    <StringView>_str,na</StringView>
     <Expand>
       <Item Name="[size]">_size</Item>
       <Item Condition="_str != _storage" Name="[capacity]">_extern._capacity</Item>


Commit: f6c37b09eafa6e028e5624cf3f1e346d9a388106
    https://github.com/scummvm/scummvm/commit/f6c37b09eafa6e028e5624cf3f1e346d9a388106
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
MSVC: Add visualisations for iterators and pointers

Changed paths:
    devtools/create_project/scripts/scummvm.natvis


diff --git a/devtools/create_project/scripts/scummvm.natvis b/devtools/create_project/scripts/scummvm.natvis
index 74003dd..5470f20 100644
--- a/devtools/create_project/scripts/scummvm.natvis
+++ b/devtools/create_project/scripts/scummvm.natvis
@@ -67,6 +67,13 @@
     <DisplayString>{_value}</DisplayString>
   </Type>
 
+  <Type Name="Common::HashMap<*,*,*,*>::IteratorImpl<*>">
+    <DisplayString>{_hashmap->_storage[_idx],na}</DisplayString>
+    <Expand>
+      <Item Name="[ptr]">_hashmap->_storage[_idx]</Item>
+    </Expand>
+  </Type>
+
   <Type Name="Common::List<*>">
     <DisplayString Condition="&_anchor == _anchor._next">{{ empty }}</DisplayString>
     <DisplayString Condition="&_anchor != _anchor._next">{{ non-empty }}</DisplayString>
@@ -83,6 +90,18 @@
     </Expand>
   </Type>
 
+  <Type Name="Common::ListInternal::Node<*>">
+    <DisplayString>{_data}</DisplayString>
+  </Type>
+
+  <Type Name="Common::ListInternal::Iterator<*>">
+    <AlternativeType Name="Common::ListInternal::ConstIterator<*>" />
+    <DisplayString>{((Common::ListInternal::Node<$T1>*)_node)->_data}</DisplayString>
+    <Expand>
+      <Item Name="[ptr]">((Common::ListInternal::Node<$T1>*)_node)->_data</Item>
+    </Expand>
+  </Type>
+
   <Type Name="Common::String">
     <DisplayString>{_str,na}</DisplayString>
     <StringView>_str,na</StringView>
@@ -96,4 +115,13 @@
       </ArrayItems>
     </Expand>
   </Type>
+
+  <Type Name="Common::SharedPtr<*>">
+    <DisplayString Condition="_pointer == 0">nullptr</DisplayString>
+    <DisplayString Condition="_pointer != 0">{*_pointer}</DisplayString>
+    <Expand>
+      <Item Condition="_pointer != 0" Name="[ptr]">_pointer</Item>
+      <Item Condition="_refCount != 0" Name="[refCount]">*_refCount</Item>
+    </Expand>
+  </Type>
 </AutoVisualizer>


Commit: 5004c331c9926fb4117d597d792e950bc27ba39e
    https://github.com/scummvm/scummvm/commit/5004c331c9926fb4117d597d792e950bc27ba39e
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
MSVC: Fix natvis not being added to project in VS2017

Changed paths:
    devtools/create_project/msbuild.cpp


diff --git a/devtools/create_project/msbuild.cpp b/devtools/create_project/msbuild.cpp
index 485e8b4..ba4833e 100644
--- a/devtools/create_project/msbuild.cpp
+++ b/devtools/create_project/msbuild.cpp
@@ -190,8 +190,8 @@ void MSBuildProvider::createProjectFile(const std::string &name, const std::stri
 		project << "\t</ItemGroup>\n";
 	}
 
-	// Visual Studio 2015 automatically imports natvis files that are part of the project
-	if (name == PROJECT_NAME && _version == 14) {
+	// Visual Studio 2015 and up automatically import natvis files that are part of the project
+	if (name == PROJECT_NAME && _version >= 14) {
 		project << "\t<ItemGroup>\n";
 		project << "\t\t<None Include=\"" << setup.srcDir << "/devtools/create_project/scripts/scummvm.natvis\" />\n";
 		project << "\t</ItemGroup>\n";


Commit: 35ea621a4ef883b0735c827d5d5c126b86451e3c
    https://github.com/scummvm/scummvm/commit/35ea621a4ef883b0735c827d5d5c126b86451e3c
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
MSVC: Add visualiser for unicode strings

Changed paths:
    devtools/create_project/scripts/scummvm.natvis


diff --git a/devtools/create_project/scripts/scummvm.natvis b/devtools/create_project/scripts/scummvm.natvis
index 5470f20..8d83924 100644
--- a/devtools/create_project/scripts/scummvm.natvis
+++ b/devtools/create_project/scripts/scummvm.natvis
@@ -108,7 +108,21 @@
     <Expand>
       <Item Name="[size]">_size</Item>
       <Item Condition="_str != _storage" Name="[capacity]">_extern._capacity</Item>
-      <Item Condition="_str != _storage" Name="[refCount]">*_extern._refCount</Item>
+      <Item Condition="_str != _storage && _extern._refCount != 0" Name="[refCount]">*_extern._refCount</Item>
+      <ArrayItems>
+        <Size>_size</Size>
+        <ValuePointer>_str</ValuePointer>
+      </ArrayItems>
+    </Expand>
+  </Type>
+
+  <Type Name="Common::U32String">
+    <DisplayString>{_str,s32}</DisplayString>
+    <StringView>_str,s32</StringView>
+    <Expand>
+      <Item Name="[size]">_size</Item>
+      <Item Condition="_str != _storage" Name="[capacity]">_extern._capacity</Item>
+      <Item Condition="_str != _storage && _extern._refCount != 0" Name="[refCount]">*_extern._refCount</Item>
       <ArrayItems>
         <Size>_size</Size>
         <ValuePointer>_str</ValuePointer>


Commit: ddb3b6fba74be5d075fb811e1bb30427aeb56626
    https://github.com/scummvm/scummvm/commit/ddb3b6fba74be5d075fb811e1bb30427aeb56626
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
MSVC: Fix resource file not including translations.dat

Changed paths:
    devtools/create_project/msbuild.cpp
    devtools/create_project/scripts/postbuild.cmd
    devtools/create_project/visualstudio.cpp


diff --git a/devtools/create_project/msbuild.cpp b/devtools/create_project/msbuild.cpp
index ba4833e..f260ad0 100644
--- a/devtools/create_project/msbuild.cpp
+++ b/devtools/create_project/msbuild.cpp
@@ -405,6 +405,7 @@ void MSBuildProvider::outputGlobalPropFile(const BuildSetup &setup, std::ofstrea
 	properties << "\t\t</Link>\n"
 	              "\t\t<ResourceCompile>\n"
 	              "\t\t\t<AdditionalIncludeDirectories>" << prefix << ";%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>\n"
+	              "\t\t\t<PreprocessorDefinitions>" << definesList << "%(PreprocessorDefinitions)</PreprocessorDefinitions>\n"
 	              "\t\t</ResourceCompile>\n"
 	              "\t</ItemDefinitionGroup>\n"
 	              "</Project>\n";
diff --git a/devtools/create_project/scripts/postbuild.cmd b/devtools/create_project/scripts/postbuild.cmd
index 31d2a94..e30d662 100644
--- a/devtools/create_project/scripts/postbuild.cmd
+++ b/devtools/create_project/scripts/postbuild.cmd
@@ -27,7 +27,6 @@ xcopy /F /Y "%~4/lib/%~3/SDL.dll"                          "%~2" 1>NUL 2>&1
 xcopy /F /Y "%~4/lib/%~3/freetype6.dll"                    "%~2" 1>NUL 2>&1
 xcopy /F /Y "%~1/backends/vkeybd/packs/vkeybd_default.zip" "%~2" 1>NUL 2>&1
 xcopy /F /Y "%~1/backends/vkeybd/packs/vkeybd_small.zip"   "%~2" 1>NUL 2>&1
-xcopy /F /Y "%~1/gui/themes/translations.dat"              "%~2" 1>NUL 2>&1
 
 
 if "%~5"=="0" goto done
diff --git a/devtools/create_project/visualstudio.cpp b/devtools/create_project/visualstudio.cpp
index d63c347..f18d625 100644
--- a/devtools/create_project/visualstudio.cpp
+++ b/devtools/create_project/visualstudio.cpp
@@ -259,6 +259,7 @@ void VisualStudioProvider::outputGlobalPropFile(const BuildSetup &setup, std::of
 	              "\t<Tool\n"
 	              "\t\tName=\"VCResourceCompilerTool\"\n"
 	              "\t\tAdditionalIncludeDirectories=\"" << prefix << "\"\n"
+	              "\t\tPreprocessorDefinitions=\"" << definesList << "\"\n"
 	              "\t/>\n"
 	              "</VisualStudioPropertySheet>\n";
 


Commit: 47b55f29c5ade774c00f1b1affbc01d0716b2732
    https://github.com/scummvm/scummvm/commit/47b55f29c5ade774c00f1b1affbc01d0716b2732
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
MSVC: Fix resource file revision include error

Changed paths:
    devtools/create_project/msbuild.cpp
    devtools/create_project/msvc.cpp
    devtools/create_project/visualstudio.cpp


diff --git a/devtools/create_project/msbuild.cpp b/devtools/create_project/msbuild.cpp
index f260ad0..2c276d5 100644
--- a/devtools/create_project/msbuild.cpp
+++ b/devtools/create_project/msbuild.cpp
@@ -380,7 +380,7 @@ void MSBuildProvider::outputGlobalPropFile(const BuildSetup &setup, std::ofstrea
 	              "\t\t<ClCompile>\n"
 	              "\t\t\t<DisableLanguageExtensions>true</DisableLanguageExtensions>\n"
 	              "\t\t\t<DisableSpecificWarnings>" << warnings << ";%(DisableSpecificWarnings)</DisableSpecificWarnings>\n"
-	              "\t\t\t<AdditionalIncludeDirectories>.;" << prefix << ";" << prefix << "\\engines;" << (setup.tests ? prefix + "\\test\\cxxtest;" : "") << "$(TargetDir);%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>\n"
+	              "\t\t\t<AdditionalIncludeDirectories>.;" << prefix << ";" << prefix << "\\engines;" << (setup.tests ? prefix + "\\test\\cxxtest;" : "") << "%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>\n"
 	              "\t\t\t<PreprocessorDefinitions>" << definesList << "%(PreprocessorDefinitions)</PreprocessorDefinitions>\n"
 	              "\t\t\t<ExceptionHandling>" << ((setup.devTools || setup.tests) ? "Sync" : "") << "</ExceptionHandling>\n";
 
@@ -404,7 +404,7 @@ void MSBuildProvider::outputGlobalPropFile(const BuildSetup &setup, std::ofstrea
 
 	properties << "\t\t</Link>\n"
 	              "\t\t<ResourceCompile>\n"
-	              "\t\t\t<AdditionalIncludeDirectories>" << prefix << ";%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>\n"
+	              "\t\t\t<AdditionalIncludeDirectories>.;" << prefix << ";%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>\n"
 	              "\t\t\t<PreprocessorDefinitions>" << definesList << "%(PreprocessorDefinitions)</PreprocessorDefinitions>\n"
 	              "\t\t</ResourceCompile>\n"
 	              "\t</ItemDefinitionGroup>\n"
diff --git a/devtools/create_project/msvc.cpp b/devtools/create_project/msvc.cpp
index e6b47fe..3fd8d2b 100644
--- a/devtools/create_project/msvc.cpp
+++ b/devtools/create_project/msvc.cpp
@@ -172,7 +172,7 @@ std::string MSVCProvider::getPreBuildEvent() const {
 	cmdLine = "@echo off\n"
 	          "echo Executing Pre-Build script...\n"
 	          "echo.\n"
-	          "@call "$(SolutionDir)../../devtools/create_project/scripts/prebuild.cmd" "$(SolutionDir)/../.."  "$(TargetDir)"\n"
+	          "@call "$(SolutionDir)../../devtools/create_project/scripts/prebuild.cmd" "$(SolutionDir)/../.." "$(SolutionDir)"\n"
 	          "EXIT /B0";
 
 	return cmdLine;
diff --git a/devtools/create_project/visualstudio.cpp b/devtools/create_project/visualstudio.cpp
index f18d625..40daad6 100644
--- a/devtools/create_project/visualstudio.cpp
+++ b/devtools/create_project/visualstudio.cpp
@@ -228,7 +228,7 @@ void VisualStudioProvider::outputGlobalPropFile(const BuildSetup &setup, std::of
 	              "\t\tName=\"VCCLCompilerTool\"\n"
 	              "\t\tDisableLanguageExtensions=\"" << (setup.devTools ? "false" : "true") << "\"\n"
 	              "\t\tDisableSpecificWarnings=\"" << warnings << "\"\n"
-	              "\t\tAdditionalIncludeDirectories=\".\\;" << prefix << ";" << prefix << "\\engines;$(" << LIBS_DEFINE << ")\\include;$(" << LIBS_DEFINE << ")\\include\\SDL;" << (setup.tests ? prefix + "\\test\\cxxtest;" : "") << "$(TargetDir)\"\n"
+	              "\t\tAdditionalIncludeDirectories=\".\\;" << prefix << ";" << prefix << "\\engines;$(" << LIBS_DEFINE << ")\\include;$(" << LIBS_DEFINE << ")\\include\\SDL;" << (setup.tests ? prefix + "\\test\\cxxtest;" : "") << "\"\n"
 	              "\t\tPreprocessorDefinitions=\"" << definesList << "\"\n"
 	              "\t\tExceptionHandling=\"" << ((setup.devTools || setup.tests || _version == 14) ? "1" : "0") << "\"\n";
 
@@ -258,7 +258,7 @@ void VisualStudioProvider::outputGlobalPropFile(const BuildSetup &setup, std::of
 	              "\t/>\n"
 	              "\t<Tool\n"
 	              "\t\tName=\"VCResourceCompilerTool\"\n"
-	              "\t\tAdditionalIncludeDirectories=\"" << prefix << "\"\n"
+	              "\t\tAdditionalIncludeDirectories=\".\\;" << prefix << "\"\n"
 	              "\t\tPreprocessorDefinitions=\"" << definesList << "\"\n"
 	              "\t/>\n"
 	              "</VisualStudioPropertySheet>\n";


Commit: b66711da04a2c89b012286552a2d64bbcbb1692d
    https://github.com/scummvm/scummvm/commit/b66711da04a2c89b012286552a2d64bbcbb1692d
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
MSVC: Fix unquoted paths in build events

Changed paths:
    devtools/create_project/msvc.cpp


diff --git a/devtools/create_project/msvc.cpp b/devtools/create_project/msvc.cpp
index 3fd8d2b..1912b8d 100644
--- a/devtools/create_project/msvc.cpp
+++ b/devtools/create_project/msvc.cpp
@@ -185,7 +185,7 @@ std::string MSVCProvider::getTestPreBuildEvent(const BuildSetup &setup) const {
 	for (StringList::const_iterator it = setup.testDirs.begin(); it != setup.testDirs.end(); ++it)
 		target += " $(SolutionDir)" + *it + "*.h";
 
-	return ""$(SolutionDir)../../test/cxxtest/cxxtestgen.py" --runner=ParenPrinter --no-std --no-eh -o $(SolutionDir)test_runner.cpp" + target;
+	return ""$(SolutionDir)../../test/cxxtest/cxxtestgen.py" --runner=ParenPrinter --no-std --no-eh -o "$(SolutionDir)test_runner.cpp"" + target;
 }
 
 std::string MSVCProvider::getPostBuildEvent(bool isWin32, bool createInstaller) const {
@@ -198,7 +198,7 @@ std::string MSVCProvider::getPostBuildEvent(bool isWin32, bool createInstaller)
 
 	cmdLine += (isWin32) ? "x86" : "x64";
 
-	cmdLine += " %" LIBS_DEFINE "% ";
+	cmdLine += " "%" LIBS_DEFINE "%" ";
 
 	// Specify if installer needs to be built or not
 	cmdLine += (createInstaller ? "1" : "0");


Commit: 3091345af36b879bb1f34fc3862fa596cf92d57d
    https://github.com/scummvm/scummvm/commit/3091345af36b879bb1f34fc3862fa596cf92d57d
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
MSVC: Update post-build installer for Inno Setup

Changed paths:
    devtools/create_project/create_project.cpp
    devtools/create_project/create_project.h
    devtools/create_project/msvc.h
    devtools/create_project/scripts/installer.vbs


diff --git a/devtools/create_project/create_project.cpp b/devtools/create_project/create_project.cpp
index dd7eeba..b415882 100644
--- a/devtools/create_project/create_project.cpp
+++ b/devtools/create_project/create_project.cpp
@@ -710,7 +710,7 @@ void displayHelp(const char *exe) {
 	        "                           The default is \"12\", thus \"Visual Studio 2013\"\n"
 	        " --build-events           Run custom build events as part of the build\n"
 	        "                          (default: false)\n"
-	        " --installer              Create NSIS installer after the build (implies --build-events)\n"
+	        " --installer              Create installer after the build (implies --build-events)\n"
 	        "                          (default: false)\n"
 	        " --tools                  Create project files for the devtools\n"
 	        "                          (ignores --build-events and --installer, as well as engine settings)\n"
diff --git a/devtools/create_project/create_project.h b/devtools/create_project/create_project.h
index af4de29..932950c 100644
--- a/devtools/create_project/create_project.h
+++ b/devtools/create_project/create_project.h
@@ -245,7 +245,7 @@ struct BuildSetup {
 	bool devTools;         ///< Generate project files for the tools
 	bool tests;            ///< Generate project files for the tests
 	bool runBuildEvents;   ///< Run build events as part of the build (generate revision number and copy engine/theme data & needed files to the build folder
-	bool createInstaller;  ///< Create NSIS installer after the build
+	bool createInstaller;  ///< Create installer after the build
 	bool useSDL2;          ///< Whether to use SDL2 or not.
 
 	BuildSetup() {
diff --git a/devtools/create_project/msvc.h b/devtools/create_project/msvc.h
index 178ba8e..b25d030 100644
--- a/devtools/create_project/msvc.h
+++ b/devtools/create_project/msvc.h
@@ -105,7 +105,7 @@ protected:
 	 * Get the command line for copying data files to the build directory.
 	 *
 	 * @param	isWin32		   	Bitness of property file.
-	 * @param	createInstaller	true to NSIS create installer
+	 * @param	createInstaller	true to create installer
 	 *
 	 * @return	The post build event.
 	 */
diff --git a/devtools/create_project/scripts/installer.vbs b/devtools/create_project/scripts/installer.vbs
index 19b4eee..6fe7813 100644
--- a/devtools/create_project/scripts/installer.vbs
+++ b/devtools/create_project/scripts/installer.vbs
@@ -21,14 +21,14 @@
 '
 '/
 
-''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
-' This script calls the makensis tool to generate a NSIS Windows installer for ScummVM
+''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
+' This script calls the iscc tool to generate a Inno Setup Windows installer for ScummVM
 '
-' It tries to read the NSIS installation folder from the registry and then calls the
+' It tries to read the Inno Setup installation folder from the registry and then calls the
 ' command line script compiler to create the installer.
 '
 ' This is called from the postbuild.cmd batch file
-''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
+''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
 
 '================================================================
 ' TODO: Reduce duplication with revision.vbs script 
@@ -43,7 +43,6 @@ Dim WshShell : Set WshShell = CreateObject("WScript.Shell")
 ' Folders
 Dim rootFolder : rootFolder = ""
 Dim targetFolder : targetFolder = ""
-Dim arch : arch = ""
 
 ' Parse our command line arguments
 If ParseCommandLine() Then
@@ -54,31 +53,20 @@ End If
 '// Installer creation
 '////////////////////////////////////////////////////////////////
 Sub CreateInstaller()
-	' Get nsis installation folder
-	Dim nsisPath : nsisPath = GetNSISPath()
-	If (nsisPath = "") Then
+	' Get inno installation folder
+	Dim innoPath : innoPath = GetInnoPath()
+	If (innoPath = "") Then
 		Exit Sub
 	End If
 
-	' Preprocess architecture
-	Select Case arch
-	Case "x86"
-		arch = "win32"
-
-	Case "x64"
-		arch = "win64"
-	End Select
-
 	' Build command line
-	Dim commandLine : commandLine = """" & nsisPath & "\makensis.exe"" /V2" & _
-	                                " /Dtop_srcdir=""" & rootFolder & """" & _
-	                                " /Dstaging_dir=""" & targetFolder & """" & _
-	                                " /DARCH=""" & arch & """" & _
-	                                " """ & rootFolder & "\dists\win32\scummvm.nsi"""
+	Dim commandLine : commandLine = """" & innoPath & "\iscc.exe"" /Qp" & _
+	                                " /O""" & targetFolder & """" & _
+	                                " """ & rootFolder & "\dists\win32\scummvm.iss"""
 
 	Dim oExec: Set oExec = WshShell.Exec(commandline)
 	If Err.Number <> 0 Then
-		Wscript.StdErr.WriteLine "Error running makensis.exe!"
+		Wscript.StdErr.WriteLine "Error running iscc.exe!"
 		Exit Sub
 	End If
 
@@ -98,25 +86,25 @@ Sub CreateInstaller()
 	End If
 End Sub
 
-Function GetNSISPath()
-	' Get the directory where NSIS (should) reside(s)
-	Dim sNSIS
+Function GetInnoPath()
+	' Get the directory where Inno Setup (should) reside(s)
+	Dim sInno
 
 	' First, try with 32-bit architecture
-	sNSIS = ReadRegistryKey("HKLM", "SOFTWARE\NSIS", "", 32)
+	sInno = ReadRegistryKey("HKLM", "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\Inno Setup 5_is1", "InstallLocation", 32)
 
-	If sNSIS = "" Or IsNull(sNSIS) Then
-		' No 32-bit version of TortoiseSVN installed, try 64-bit version (doesn't hurt on 32-bit machines, it returns nothing or is ignored)
-		sNSIS = ReadRegistryKey("HKLM", "SOFTWARE\NSIS", "", 64)
+	If sInno = "" Or IsNull(sInno) Then
+		' No 32-bit version of Inno Setup installed, try 64-bit version (doesn't hurt on 32-bit machines, it returns nothing or is ignored)
+		sInno = ReadRegistryKey("HKLM", "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\Inno Setup 5_is1", "InstallLocation", 64)
 	End If
 
-	' Check if Tortoise is present
-	If sNSIS = "" Then
-		Wscript.StdErr.WriteLine "NSIS not installed!"
+	' Check if Inno Setup is present
+	If sInno = "" Then
+		Wscript.StdErr.WriteLine "Inno Setup not installed!"
 		Exit Function
 	End If
 
-	GetNSISPath = sNSIS
+	GetInnoPath = sInno
 End Function
 
 '////////////////////////////////////////////////////////////////
@@ -125,8 +113,8 @@ End Function
 Function ParseCommandLine()
 	ParseCommandLine = True
 
-	If Wscript.Arguments.Count <> 3 Then
-		Wscript.StdErr.WriteLine "[Error] Invalid number of arguments (was: " & Wscript.Arguments.Count & ", expected: 3)"
+	If Wscript.Arguments.Count <> 2 Then
+		Wscript.StdErr.WriteLine "[Error] Invalid number of arguments (was: " & Wscript.Arguments.Count & ", expected: 2)"
 
 		ParseCommandLine = False
 		Exit Function
@@ -135,7 +123,6 @@ Function ParseCommandLine()
 	' Get our arguments
 	rootFolder = Wscript.Arguments.Item(0)
 	targetFolder = Wscript.Arguments.Item(1)
-	arch = Wscript.Arguments.Item(2)
 
 	' Check that the folders are valid
 	If Not FSO.FolderExists(rootFolder) Then


Commit: e6a80868c64bf9dbefa786686b0257fef7a8f2ef
    https://github.com/scummvm/scummvm/commit/e6a80868c64bf9dbefa786686b0257fef7a8f2ef
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
MSVC: Update DLL paths in post-build script

Changed paths:
    devtools/create_project/msbuild.cpp
    devtools/create_project/msvc.cpp
    devtools/create_project/msvc.h
    devtools/create_project/scripts/postbuild.cmd
    devtools/create_project/visualstudio.cpp


diff --git a/devtools/create_project/msbuild.cpp b/devtools/create_project/msbuild.cpp
index 2c276d5..58efa88 100644
--- a/devtools/create_project/msbuild.cpp
+++ b/devtools/create_project/msbuild.cpp
@@ -339,7 +339,7 @@ void MSBuildProvider::outputProjectSettings(std::ofstream &project, const std::s
 			// Copy data files to the build folder
 			project << "\t\t<PostBuildEvent>\n"
 					   "\t\t\t<Message>Copy data files to the build folder</Message>\n"
-					   "\t\t\t<Command>" << getPostBuildEvent(isWin32, setup.createInstaller) << "</Command>\n"
+					   "\t\t\t<Command>" << getPostBuildEvent(isWin32, setup) << "</Command>\n"
 					   "\t\t</PostBuildEvent>\n";
 		} else if (setup.tests) {
 			project << "\t\t<PreBuildEvent>\n"
diff --git a/devtools/create_project/msvc.cpp b/devtools/create_project/msvc.cpp
index 1912b8d..1ca8c7f 100644
--- a/devtools/create_project/msvc.cpp
+++ b/devtools/create_project/msvc.cpp
@@ -188,7 +188,7 @@ std::string MSVCProvider::getTestPreBuildEvent(const BuildSetup &setup) const {
 	return ""$(SolutionDir)../../test/cxxtest/cxxtestgen.py" --runner=ParenPrinter --no-std --no-eh -o "$(SolutionDir)test_runner.cpp"" + target;
 }
 
-std::string MSVCProvider::getPostBuildEvent(bool isWin32, bool createInstaller) const {
+std::string MSVCProvider::getPostBuildEvent(bool isWin32, const BuildSetup &setup) const {
 	std::string cmdLine = "";
 
 	cmdLine = "@echo off\n"
@@ -196,12 +196,14 @@ std::string MSVCProvider::getPostBuildEvent(bool isWin32, bool createInstaller)
 	          "echo.\n"
 	          "@call "$(SolutionDir)../../devtools/create_project/scripts/postbuild.cmd" "$(SolutionDir)/../.." "$(OutDir)" ";
 
-	cmdLine += (isWin32) ? "x86" : "x64";
+	cmdLine += (setup.useSDL2) ? "SDL2" : "SDL";
 
-	cmdLine += " "%" LIBS_DEFINE "%" ";
+	cmdLine += " "%" LIBS_DEFINE "%/lib/";
+	cmdLine += (isWin32) ? "x86" : "x64";
+	cmdLine += "/$(Configuration)" ";
 
 	// Specify if installer needs to be built or not
-	cmdLine += (createInstaller ? "1" : "0");
+	cmdLine += (setup.createInstaller ? "1" : "0");
 
 	cmdLine += "\n"
 	           "EXIT /B0";
diff --git a/devtools/create_project/scripts/postbuild.cmd b/devtools/create_project/scripts/postbuild.cmd
index e30d662..e2ea412 100644
--- a/devtools/create_project/scripts/postbuild.cmd
+++ b/devtools/create_project/scripts/postbuild.cmd
@@ -4,27 +4,27 @@ REM ---------------------------------------------------------------
 REM -- Post-Build Script
 REM ---------------------------------------------------------------
 REM
-REM Copy engine data, themes, translation and required dlls to the
+REM Copy engine data and required dlls to the
 REM output folder and optionally create an installer
 REM
 REM Expected parameters
 REM    Root folder
 REM    Output folder
-REM    Architecture
+REM    SDL version
 REM    Libs folder
 REM    Installer ("1" to build, "0" to skip)
 
 if "%~1"=="" goto error_root
 if "%~2"=="" goto error_output
-if "%~3"=="" goto error_arch
+if "%~3"=="" goto error_sdl
 if "%~4"=="" goto error_libs
 if "%~5"=="" goto error_installer
 
 echo Copying data files
 echo.
 
-xcopy /F /Y "%~4/lib/%~3/SDL.dll"                          "%~2" 1>NUL 2>&1
-xcopy /F /Y "%~4/lib/%~3/freetype6.dll"                    "%~2" 1>NUL 2>&1
+xcopy /F /Y "%~4/%~3.dll"                                  "%~2" 1>NUL 2>&1
+xcopy /F /Y "%~4/WinSparkle.dll"                           "%~2" 1>NUL 2>&1
 xcopy /F /Y "%~1/backends/vkeybd/packs/vkeybd_default.zip" "%~2" 1>NUL 2>&1
 xcopy /F /Y "%~1/backends/vkeybd/packs/vkeybd_small.zip"   "%~2" 1>NUL 2>&1
 
@@ -33,7 +33,7 @@ if "%~5"=="0" goto done
 
 echo Running installer script
 echo.
- at call cscript "%~1/devtools/create_project/scripts/installer.vbs" "%~1" "%~2" "%~3" 1>NUL
+ at call cscript "%~1/devtools/create_project/scripts/installer.vbs" "%~1" "%~2" 1>NUL
 if not %errorlevel% == 0 goto error_script
 goto done
 
@@ -45,8 +45,8 @@ goto done
 echo Invalid output folder (%~2)!
 goto done
 
-:error_arch
-echo Invalid arch parameter (was: %~3, allowed: x86, x64)!
+:error_sdl
+echo Invalid SDL parameter (was: %~3, allowed: SDL, SDL2)!
 goto done
 
 :error_libs
diff --git a/devtools/create_project/visualstudio.cpp b/devtools/create_project/visualstudio.cpp
index 40daad6..110e643 100644
--- a/devtools/create_project/visualstudio.cpp
+++ b/devtools/create_project/visualstudio.cpp
@@ -171,7 +171,7 @@ void VisualStudioProvider::outputBuildEvents(std::ostream &project, const BuildS
 		           "\t\t\t\tCommandLine=\"" << getPreBuildEvent() << "\"\n"
 		           "\t\t\t/>\n"
 		           "\t\t\t<Tool\tName=\"VCPostBuildEventTool\"\n"
-		           "\t\t\t\tCommandLine=\"" << getPostBuildEvent(isWin32, setup.createInstaller) << "\"\n"
+		           "\t\t\t\tCommandLine=\"" << getPostBuildEvent(isWin32, setup) << "\"\n"
 		           "\t\t\t/>\n";
 	}
 


Commit: 4f761d60028a3bc5263e199993cacf3605921ced
    https://github.com/scummvm/scummvm/commit/4f761d60028a3bc5263e199993cacf3605921ced
Author: SupSuper (supsuper at gmail.com)
Date: 2018-12-23T18:39:06+02:00

Commit Message:
BUILD: Update MSVC versions in ideprojects target

Changed paths:
    ports.mk


diff --git a/ports.mk b/ports.mk
index e08d5cb..aa63a11 100644
--- a/ports.mk
+++ b/ports.mk
@@ -468,6 +468,10 @@ endif
 	@cd $(srcdir)/dists/msvc11 && ../../devtools/create_project/create_project ../.. --msvc --msvc-version 11 >/dev/null && git add -f engines/plugins_table.h *.sln *.vcxproj *.vcxproj.filters *.props
 	@echo Creating MSVC12 project files...
 	@cd $(srcdir)/dists/msvc12 && ../../devtools/create_project/create_project ../.. --msvc --msvc-version 12 >/dev/null && git add -f engines/plugins_table.h *.sln *.vcxproj *.vcxproj.filters *.props
+	@echo Creating MSVC14 project files...
+	@cd $(srcdir)/dists/msvc14 && ../../devtools/create_project/create_project ../.. --msvc --msvc-version 14 >/dev/null && git add -f engines/plugins_table.h *.sln *.vcxproj *.vcxproj.filters *.props
+	@echo Creating MSVC15 project files...
+	@cd $(srcdir)/dists/msvc15 && ../../devtools/create_project/create_project ../.. --msvc --msvc-version 15 >/dev/null && git add -f engines/plugins_table.h *.sln *.vcxproj *.vcxproj.filters *.props
 	@echo
 	@echo All is done.
 	@echo Now run





More information about the Scummvm-git-logs mailing list
diff --git a/devtools/create_project/msvc.h b/devtools/create_project/msvc.h
index b25d030..ce228b8 100644
--- a/devtools/create_project/msvc.h
+++ b/devtools/create_project/msvc.h
@@ -104,12 +104,12 @@ protected:
 	/**
 	 * Get the command line for copying data files to the build directory.
 	 *
 	 * @param	isWin32		   	Bitness of property file.
 	 * @param	createInstaller	true to create installer
 	 *
 	 * @return	The post build event.
 	 */
-	std::string getPostBuildEvent(bool isWin32, bool createInstaller) const;
+	std::string getPostBuildEvent(bool isWin32, const BuildSetup &setup) const;
 };
 
 } // End of CreateProjectTool namespace
@@ -104,12 +104,12 @@ protected:
 	 * Get the command line for copying data files to the build directory.
 	 *
-	 * @param	isWin32		   	Bitness of property file.
-	 * @param	createInstaller	true to create installer
+	 * @param	isWin32	Bitness of property file.
+	 * @param	setup	Description of the desired build setup.
 	 *
 	 * @return	The post build event.